@@ -1,8 +1,32 @@
 from .resource import Resource
 from hellosign_sdk.utils import HSAccessTokenAuth
 
-class Account(Resource):
+#
+# The MIT License (MIT)
+# 
+# Copyright (C) 2014 hellosign.com
+# 
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+#
 
+
+class Account(Resource):
     ''' Contains information about an account and its settings.
 
     Attributes:
@@ -23,7 +47,10 @@ class Account(Resource):
 
         callback_url (str): The URL that HelloSign events will be POSTed to
 
-        role_code (str): The membership role for the team. O = Owner, M = Member
+        role_code (str): The membership role for the team. 
+            a = Admin, 
+            m = Member
+            d = Developer
 
     Examples:
         To print the account_id
@@ -35,7 +62,11 @@ class Account(Resource):
 
     '''
 
-    def __init__(self, jsonstr=None, key=None):
+    ROLE_ADMIN = 'a'
+    ROLE_MEMBER = 'm'
+    ROLE_DEVELOPER = 'd'
+
+    def __init__(self, jsonstr=None, key=None, warnings=None):
         ''' Initialization of the object
 
         Args:
@@ -45,8 +76,9 @@ class Account(Resource):
                 of the object
             key (str): Optional key to use with jsonstr. If `key` exists, we'll
                 load the data of `jsonstr[key]` instead of the whole `jsonstr`
+            warnings (list): List of associated warnings
         '''
-        super(Account, self).__init__(jsonstr, key)
+        super(Account, self).__init__(jsonstr, key, warnings)
         if self.json_data and 'oauth' in self.json_data:
             oauth = HSAccessTokenAuth.from_response(self.json_data['oauth'])
             self.json_data['oauth'] = oauth
